Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Base64Cleaner ¶
type Base64Cleaner struct {
// Report of non-whitespace characters detected while cleaning base64 data.
Errors []error
// contains filtered or unexported fields
}
Base64Cleaner improves the tolerance of in Go's built-in base64 decoder by stripping out characters that would cause decoding to fail.
func NewBase64Cleaner ¶
func NewBase64Cleaner(r io.Reader) *Base64Cleaner
NewBase64Cleaner returns a Base64Cleaner object for the specified reader. Base64Cleaner implements the io.Reader interface.
type QPCleaner ¶
type QPCleaner struct {
// contains filtered or unexported fields
}
QPCleaner scans quoted printable content for invalid characters and encodes them so that Go's quoted-printable decoder does not abort with an error.
func NewQPCleaner ¶
NewQPCleaner returns a QPCleaner for the specified reader.
Click to show internal directories.
Click to hide internal directories.