pyapp_nodejs

package
v0.3.71 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2025 License: BSD-3-Clause Imports: 3 Imported by: 0

README

Node.js Virtual Environment.

nodeenv (node.js virtual environment) is a tool to create isolated node.js environments.

It creates an environment that has its own installation directories, that doesn’t share libraries with other node.js virtual environments.

Also the new environment can be integrated with the environment which was built by virtualenv (python).

If you use nodeenv feel free to add your project on wiki: Who-Uses-Nodeenv.

https://pypi.org/project/nodeenv/

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewN8n

func NewN8n(venv pyvenv_commons.IVenv) (instance *nodeapp_n8n.N8n)

func NewNodeJs

func NewNodeJs(venv pyvenv_commons.IVenv) (instance *nodejs.NodeJs)

NewNodeJs creates a new instance of NodeJs linked to the specified Python virtual environment (IVenv).

Types

This section is empty.

Directories

Path Synopsis
nodevenv_apps

Jump to