Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type UserHomeHelper ¶
type UserHomeHelper struct {
DisableCache bool
// contains filtered or unexported fields
}
var UserHome *UserHomeHelper
func (*UserHomeHelper) Dir ¶
func (instance *UserHomeHelper) Dir() (result string, err error)
Dir returns the home directory for the executing user.
This uses an OS-specific method for discovering the home directory. An error is returned if a home directory cannot be detected.
func (*UserHomeHelper) Expand ¶
func (instance *UserHomeHelper) Expand(path string) (response string, err error)
Expand expands the path to include the home directory if the path is prefixed with `~`. If it isn't prefixed with `~`, the path is returned as-is.
func (*UserHomeHelper) Reset ¶
func (instance *UserHomeHelper) Reset()
Reset clears the cache, forcing the next call to Dir to re-detect the home directory. This generally never has to be called, but can be useful in tests if you're modifying the home directory via the HOME env var or something.
Click to show internal directories.
Click to hide internal directories.