Documentation
¶
Index ¶
- type OSEnvironment
- func (instance *OSEnvironment) Append(name string, value string) (err error)
- func (instance *OSEnvironment) Close()
- func (instance *OSEnvironment) Dir() string
- func (instance *OSEnvironment) DirBin() string
- func (instance *OSEnvironment) Environment() (response []string)
- func (instance *OSEnvironment) IsOpen() (response bool)
- func (instance *OSEnvironment) Map() (response map[string]interface{})
- func (instance *OSEnvironment) NameExists(name string) (response bool)
- func (instance *OSEnvironment) Names() (response []string)
- func (instance *OSEnvironment) Open(root string) (err error)
- func (instance *OSEnvironment) PathAdd(path string) (err error)
- func (instance *OSEnvironment) PathContain(path string) (response bool)
- func (instance *OSEnvironment) PathEnum(prefix ...string) (response []string)
- func (instance *OSEnvironment) Set(name string, value string, overwrite bool) (err error)
- func (instance *OSEnvironment) String() string
- type PythonVenv
- func (instance *PythonVenv) ActivateEnv() (err error)
- func (instance *PythonVenv) DeactivateEnv()
- func (instance *PythonVenv) DirEnv() string
- func (instance *PythonVenv) DirEnvBin() string
- func (instance *PythonVenv) DirRoot() string
- func (instance *PythonVenv) Environment() (response []string)
- func (instance *PythonVenv) EnvironmentAppend(name, value string) (response bool)
- func (instance *PythonVenv) EnvironmentSet(name, value string) (response bool)
- func (instance *PythonVenv) InitializeAll() (response []string, err error)
- func (instance *PythonVenv) InitializeEnv() (err error)
- func (instance *PythonVenv) IsActive() (response bool)
- func (instance *PythonVenv) IsInitialized() (response bool)
- func (instance *PythonVenv) NewAppDocling() (response *pyapp_docling.Docling)
- func (instance *PythonVenv) NewAppN8n() (response *nodeapp_n8n.N8n)
- func (instance *PythonVenv) NewAppNodeJs() (response *nodejs.NodeJs)
- func (instance *PythonVenv) NewAppWhisper() (response *pyapp_whisper.Whisper)
- func (instance *PythonVenv) PathAdd(path string) (response bool)
- func (instance *PythonVenv) PathEnum(prefix ...string) (response []string)
- func (instance *PythonVenv) PipInstall(args ...string) (response string, err error)
- func (instance *PythonVenv) PipUpgrade() (response string, err error)
- func (instance *PythonVenv) PipVersion() (response string, err error)
- func (instance *PythonVenv) Run(args ...string) (response string, err error)
- func (instance *PythonVenv) RunModule(args ...string) (response string, err error)
- func (instance *PythonVenv) TryPathAdd(path string) (err error)
- func (instance *PythonVenv) UtilsWhich(executables ...string) (response []string, err error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OSEnvironment ¶
type OSEnvironment struct {
// contains filtered or unexported fields
}
OSEnvironment represents the configuration and environment data for an operating system process.
func NewOSEnvironment ¶
func NewOSEnvironment() (instance *OSEnvironment)
func (*OSEnvironment) Append ¶ added in v0.3.65
func (instance *OSEnvironment) Append(name string, value string) (err error)
func (*OSEnvironment) Close ¶
func (instance *OSEnvironment) Close()
func (*OSEnvironment) Dir ¶
func (instance *OSEnvironment) Dir() string
func (*OSEnvironment) DirBin ¶
func (instance *OSEnvironment) DirBin() string
func (*OSEnvironment) Environment ¶
func (instance *OSEnvironment) Environment() (response []string)
func (*OSEnvironment) IsOpen ¶
func (instance *OSEnvironment) IsOpen() (response bool)
func (*OSEnvironment) Map ¶
func (instance *OSEnvironment) Map() (response map[string]interface{})
func (*OSEnvironment) NameExists ¶ added in v0.3.65
func (instance *OSEnvironment) NameExists(name string) (response bool)
func (*OSEnvironment) Names ¶ added in v0.3.65
func (instance *OSEnvironment) Names() (response []string)
func (*OSEnvironment) Open ¶
func (instance *OSEnvironment) Open(root string) (err error)
func (*OSEnvironment) PathAdd ¶
func (instance *OSEnvironment) PathAdd(path string) (err error)
func (*OSEnvironment) PathContain ¶
func (instance *OSEnvironment) PathContain(path string) (response bool)
func (*OSEnvironment) PathEnum ¶
func (instance *OSEnvironment) PathEnum(prefix ...string) (response []string)
func (*OSEnvironment) Set ¶ added in v0.3.65
func (instance *OSEnvironment) Set(name string, value string, overwrite bool) (err error)
func (*OSEnvironment) String ¶
func (instance *OSEnvironment) String() string
type PythonVenv ¶
type PythonVenv struct {
// contains filtered or unexported fields
}
PythonVenv represents a Python virtual environment, storing its root directory and the command to execute Python. https://packaging.python.org/en/latest/guides/installing-using-pip-and-virtual-environments/
func NewPythonVenv ¶
func NewPythonVenv(root string) (instance *PythonVenv)
func (*PythonVenv) ActivateEnv ¶
func (instance *PythonVenv) ActivateEnv() (err error)
func (*PythonVenv) DeactivateEnv ¶
func (instance *PythonVenv) DeactivateEnv()
func (*PythonVenv) DirEnv ¶
func (instance *PythonVenv) DirEnv() string
func (*PythonVenv) DirEnvBin ¶
func (instance *PythonVenv) DirEnvBin() string
func (*PythonVenv) DirRoot ¶
func (instance *PythonVenv) DirRoot() string
func (*PythonVenv) Environment ¶ added in v0.3.65
func (instance *PythonVenv) Environment() (response []string)
func (*PythonVenv) EnvironmentAppend ¶ added in v0.3.65
func (instance *PythonVenv) EnvironmentAppend(name, value string) (response bool)
func (*PythonVenv) EnvironmentSet ¶ added in v0.3.65
func (instance *PythonVenv) EnvironmentSet(name, value string) (response bool)
func (*PythonVenv) InitializeAll ¶
func (instance *PythonVenv) InitializeAll() (response []string, err error)
InitializeAll initializes and activates the Python virtual environment, upgrades pip, and returns status messages or errors.
func (*PythonVenv) InitializeEnv ¶
func (instance *PythonVenv) InitializeEnv() (err error)
func (*PythonVenv) IsActive ¶
func (instance *PythonVenv) IsActive() (response bool)
func (*PythonVenv) IsInitialized ¶
func (instance *PythonVenv) IsInitialized() (response bool)
func (*PythonVenv) NewAppDocling ¶
func (instance *PythonVenv) NewAppDocling() (response *pyapp_docling.Docling)
func (*PythonVenv) NewAppN8n ¶ added in v0.3.65
func (instance *PythonVenv) NewAppN8n() (response *nodeapp_n8n.N8n)
func (*PythonVenv) NewAppNodeJs ¶ added in v0.3.65
func (instance *PythonVenv) NewAppNodeJs() (response *nodejs.NodeJs)
func (*PythonVenv) NewAppWhisper ¶
func (instance *PythonVenv) NewAppWhisper() (response *pyapp_whisper.Whisper)
func (*PythonVenv) PathAdd ¶
func (instance *PythonVenv) PathAdd(path string) (response bool)
func (*PythonVenv) PathEnum ¶
func (instance *PythonVenv) PathEnum(prefix ...string) (response []string)
func (*PythonVenv) PipInstall ¶
func (instance *PythonVenv) PipInstall(args ...string) (response string, err error)
func (*PythonVenv) PipUpgrade ¶
func (instance *PythonVenv) PipUpgrade() (response string, err error)
func (*PythonVenv) PipVersion ¶
func (instance *PythonVenv) PipVersion() (response string, err error)
func (*PythonVenv) Run ¶
func (instance *PythonVenv) Run(args ...string) (response string, err error)
Run executes a command within the Python virtual environment with the provided arguments. It returns the command's response and any error encountered during execution.
func (*PythonVenv) RunModule ¶
func (instance *PythonVenv) RunModule(args ...string) (response string, err error)
RunModule executes a Python module within the virtual environment using the provided arguments. Returns the command output (response) and any error encountered during execution. Module executor add python exec with -m param on top of the request https://docs.python.org/3/using/cmdline.html
func (*PythonVenv) TryPathAdd ¶ added in v0.3.47
func (instance *PythonVenv) TryPathAdd(path string) (err error)
func (*PythonVenv) UtilsWhich ¶
func (instance *PythonVenv) UtilsWhich(executables ...string) (response []string, err error)